( cd opt/kde/share/doc/HTML/it/ark ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ark ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kdf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kig ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kig ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/juk ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/juk ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ktuberling ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ktuberling ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/amor ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/amor ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kdat ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kdat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kdvi ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kdvi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kgeo ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kgeo ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kget ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kget ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kgpg ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kgpg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmag ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmag ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmid ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmid ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmix ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmix ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kodo ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kodo ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kolf ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kolf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kpat ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kpat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kpdf ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kpdf ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/korn ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/korn ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/krec ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/krec ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kscd ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kscd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ksim ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ksim ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/lisa ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/lisa ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kxkb ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kxkb ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kalzium ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kalzium ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/katomic ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ksysguard ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ksysguard ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kbounce ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kdearch ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kdearch ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kbattleship ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kbattleship ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kaboodle ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kaboodle ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/khangman ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/khangman ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kfloppy ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kfloppy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kpercentage ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kpercentage ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kandy ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kandy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcalc ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcalc ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kdesu ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kdesu ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcron ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcron ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kedit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kfind ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kfind ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kiten ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kiten ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmail ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmail ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmoon ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmoon ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kooka ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kooka ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ksame ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ksame ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ksysv ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ksysv ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ktron ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ktron ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kuser ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kuser ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kwin4 ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kwin4 ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/lskat ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/lskat ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kgoldrunner ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kgoldrunner ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcoloredit ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/klipper ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/klipper ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kvoctrain ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kvoctrain ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmousetool ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmousetool ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ksnapshot ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/klinkstatus ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kompare ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kompare ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/konsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/konsole ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kpackage ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kpackage ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kshisen ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kshisen ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ksirtet ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ksirtet ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/konquest ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/konquest ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kspaceduel ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kturtle ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kturtle ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kverbos ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kverbos ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kweather ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kweather ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kxsldbg ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kxsldbg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kbugbuster ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmenuedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kioslave ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kioslave ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/flashkard ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/flashkard ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kbackgammon ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf fdl-license )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/fdl-license fdl-license )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf qpl-license.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/qpl-license.html qpl-license.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf x11-license.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/x11-license.html x11-license.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf 1.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/1.png 1.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf xml.dcl )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/xml.dcl xml.dcl )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf 2.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/2.png 2.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf 3.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/3.png 3.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf 4.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/4.png 4.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf 5.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/5.png 5.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf 6.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/6.png 6.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf 7.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/7.png 7.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf 8.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/8.png 8.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf 9.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/9.png 9.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf headerbg.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/headerbg.png headerbg.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf gpl-license.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/gpl-license.html gpl-license.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf mainheader.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/mainheader.html mainheader.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf grad.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/grad.png grad.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-web.css )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf lgpl-license.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf doxygen.css )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doxygen.css doxygen.css )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf web-doctop.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/web-doctop.png web-doctop.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-default.css )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-default.css kde-default.css )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf kmenu.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kmenu.png kmenu.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf footer.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/footer.html footer.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-common.css )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf appheader.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/appheader.html appheader.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop1.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop2.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf shadow.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/shadow.png shadow.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde_logo.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf docheadergears.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf fdl-license.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop1a.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf 10.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/10.png 10.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf doctop1b.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/doctop1b.png doctop1b.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf lgpl-license )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/lgpl-license lgpl-license )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf mainfooter.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/mainfooter.html mainfooter.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf bottom1.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom1.png bottom1.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf bottom2.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf header.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/header.html header.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf gpl-license )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/gpl-license gpl-license )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf kde-localised.css.template )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/kde-localised.css.template kde-localised.css.template )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf bsd-license.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/bsd-license.html bsd-license.html )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf web-docbottom.png )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
( cd opt/kde/share/doc/HTML/it/common ; rm -rf artistic-license.html )
( cd opt/kde/share/doc/HTML/it/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
( cd opt/kde/share/doc/HTML/it/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/desktopbehavior ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/desktopbehavior ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/lanbrowser ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/lanbrowser ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/panelappearance ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/panelappearance ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kbabel ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kbabel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kamera ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kamera ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kasteroids ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kasteroids ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kbruch ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kbruch ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/keduca ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmessedwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kdevelop ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kdevelop ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kicker ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kicker ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/klatin ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/klatin ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/klines ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/klines ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmines ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmines ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmouth ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmouth ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmplot ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmplot ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/knotes ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/knotes ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kopete ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kopete ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kpoker ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kpoker ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kruler ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kruler ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ksnake ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ksnake ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kspell ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kspell ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kstars ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ktimer ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ktimer ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ktouch ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ktouch ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kwrite ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kwrite ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/megami ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/megami ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kreversi ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kreversi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/noatun ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/noatun ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ksplashml ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ksplashml ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kdebugdialog ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kdebugdialog ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kblackbox ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kblackbox ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kcharselect ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kcharselect ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/quanta ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kuickshow ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kuickshow ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kde_app_devel ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kommander ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kommander ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kiconedit ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kiconedit ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/klettres ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/klettres ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kfouleggs ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kghostview ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kghostview ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/klickety ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/klickety ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kleopatra ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kleopatra ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kjumpingcube ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kenolaba ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kenolaba ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kgpgcertmanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kworldclock ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kworldclock ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/ksokoban ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/ksokoban ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kteatime ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kteatime ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kmathtool ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kmathtool ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/umbrello ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/umbrello ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/konqueror ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/konqueror ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/kwordquiz ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/korganizer ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/korganizer ; ln -sf /opt/kde/share/doc/HTML/it/common common )
( cd opt/kde/share/doc/HTML/it/atlantik ; rm -rf common )
( cd opt/kde/share/doc/HTML/it/atlantik ; ln -sf /opt/kde/share/doc/HTML/it/common common )
